package com.xuecheng.content;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xuecheng.base.model.PageParams;
import com.xuecheng.base.model.PageResult;
import com.xuecheng.content.mapper.CourseBaseMapper;
import com.xuecheng.model.dto.QueryCourseParamDto;
import com.xuecheng.model.po.CourseBase;
import org.apache.commons.lang.StringUtils;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import java.util.List;

/**
 * @author ZZY
 * @version 1.0
 * @description 测试查询课程
 * @date 2023/3/16 10:37
 */
@SpringBootTest(classes = XuechengPlusContentApplication.class)
public class CourseBaseMapperTests {
    @Autowired
    CourseBaseMapper courseBaseMapper;

    @Test
    void testCourseBaseMapper() {
        //查询条件
        QueryCourseParamDto queryCourseParamDto = new QueryCourseParamDto();
        CourseBase courseBase = courseBaseMapper.selectById(18L);
        Assertions.assertNotNull(courseBase);
        queryCourseParamDto.setCourseName("java");
        queryCourseParamDto.setPublishStatus("203001");
        LambdaQueryWrapper<CourseBase> queryWrapper = new LambdaQueryWrapper<>();
        //模糊查询 名称
        queryWrapper.like(StringUtils.isNotEmpty(queryCourseParamDto.getCourseName()), CourseBase::getName, queryCourseParamDto.getCourseName());
        //精确查询课程审核状态
        queryWrapper.eq(StringUtils.isNotEmpty(queryCourseParamDto.getAuditStatus()), CourseBase::getAuditStatus, queryCourseParamDto.getAuditStatus());
        //按课程发布查询
        queryWrapper.eq(StringUtils.isNotEmpty(queryCourseParamDto.getPublishStatus()), CourseBase::getStatus, queryCourseParamDto.getPublishStatus());
        //分页插件
        PageParams pageParams = new PageParams();
        pageParams.setPageNo(1L);
        pageParams.setPageSize(2L);
        Page<CourseBase> page = new Page<>(pageParams.getPageNo(), pageParams.getPageSize());
        Page<CourseBase> result = courseBaseMapper.selectPage(page, queryWrapper);
        //数据列表
        //1.数据
        List<CourseBase> items = result.getRecords();
        //2.总记录数
        long counts = result.getTotal();
        PageResult<CourseBase> pageResult = new PageResult<CourseBase>(items, counts, pageParams.getPageNo(), pageParams.getPageSize());
        System.out.println(pageResult);
    }
}
